Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.PostCategory) predicate.PostCategory
- func CategoryEQ(v Category) predicate.PostCategory
- func CategoryIn(vs ...Category) predicate.PostCategory
- func CategoryNEQ(v Category) predicate.PostCategory
- func CategoryNotIn(vs ...Category) predicate.PostCategory
- func CategoryValidator(c Category) error
- func CreatedAt(v time.Time) predicate.PostCategory
- func CreatedAtEQ(v time.Time) predicate.PostCategory
- func CreatedAtGT(v time.Time) predicate.PostCategory
- func CreatedAtGTE(v time.Time) predicate.PostCategory
- func CreatedAtIn(vs ...time.Time) predicate.PostCategory
- func CreatedAtLT(v time.Time) predicate.PostCategory
- func CreatedAtLTE(v time.Time) predicate.PostCategory
- func CreatedAtNEQ(v time.Time) predicate.PostCategory
- func CreatedAtNotIn(vs ...time.Time) predicate.PostCategory
- func HasPost() predicate.PostCategory
- func HasPostWith(preds ...predicate.Post) predicate.PostCategory
- func ID(id uuid.UUID) predicate.PostCategory
- func IDEQ(id uuid.UUID) predicate.PostCategory
- func IDGT(id uuid.UUID) predicate.PostCategory
- func IDGTE(id uuid.UUID) predicate.PostCategory
- func IDIn(ids ...uuid.UUID) predicate.PostCategory
- func IDLT(id uuid.UUID) predicate.PostCategory
- func IDLTE(id uuid.UUID) predicate.PostCategory
- func IDNEQ(id uuid.UUID) predicate.PostCategory
- func IDNotIn(ids ...uuid.UUID) predicate.PostCategory
- func Not(p predicate.PostCategory) predicate.PostCategory
- func Or(predicates ...predicate.PostCategory) predicate.PostCategory
- func UpdatedAt(v time.Time) predicate.PostCategory
- func UpdatedAtEQ(v time.Time) predicate.PostCategory
- func UpdatedAtGT(v time.Time) predicate.PostCategory
- func UpdatedAtGTE(v time.Time) predicate.PostCategory
- func UpdatedAtIn(vs ...time.Time) predicate.PostCategory
- func UpdatedAtLT(v time.Time) predicate.PostCategory
- func UpdatedAtLTE(v time.Time) predicate.PostCategory
- func UpdatedAtNEQ(v time.Time) predicate.PostCategory
- func UpdatedAtNotIn(vs ...time.Time) predicate.PostCategory
- func ValidColumn(column string) bool
- type Category
- type OrderOption
Constants ¶
const ( // Label holds the string label denoting the postcategory type in the database. Label = "post_category" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldCategory holds the string denoting the category field in the database. FieldCategory = "category" // EdgePost holds the string denoting the post edge name in mutations. EdgePost = "post" // Table holds the table name of the postcategory in the database. Table = "post_categories" // PostTable is the table that holds the post relation/edge. PostTable = "post_categories" // PostInverseTable is the table name for the Post entity. // It exists in this package in order to avoid circular dependency with the "post" package. PostInverseTable = "posts" // PostColumn is the table column denoting the post relation/edge. PostColumn = "post_categories" )
Variables ¶
var ( // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldUpdatedAt, FieldCreatedAt, FieldCategory, }
Columns holds all SQL columns for postcategory fields.
var ForeignKeys = []string{
"post_categories",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "post_categories" table and are not defined as standalone fields in the schema.
Functions ¶
func And ¶
func And(predicates ...predicate.PostCategory) predicate.PostCategory
And groups predicates with the AND operator between them.
func CategoryEQ ¶
func CategoryEQ(v Category) predicate.PostCategory
CategoryEQ applies the EQ predicate on the "category" field.
func CategoryIn ¶
func CategoryIn(vs ...Category) predicate.PostCategory
CategoryIn applies the In predicate on the "category" field.
func CategoryNEQ ¶
func CategoryNEQ(v Category) predicate.PostCategory
CategoryNEQ applies the NEQ predicate on the "category" field.
func CategoryNotIn ¶
func CategoryNotIn(vs ...Category) predicate.PostCategory
CategoryNotIn applies the NotIn predicate on the "category" field.
func CategoryValidator ¶
CategoryValidator is a validator for the "category" field enum values. It is called by the builders before save.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.PostCategory
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.PostCategory
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.PostCategory
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.PostCategory
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.PostCategory
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.PostCategory
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.PostCategory
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.PostCategory
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.PostCategory
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func HasPost ¶
func HasPost() predicate.PostCategory
HasPost applies the HasEdge predicate on the "post" edge.
func HasPostWith ¶
func HasPostWith(preds ...predicate.Post) predicate.PostCategory
HasPostWith applies the HasEdge predicate on the "post" edge with a given conditions (other predicates).
func IDEQ ¶
func IDEQ(id uuid.UUID) predicate.PostCategory
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id uuid.UUID) predicate.PostCategory
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id uuid.UUID) predicate.PostCategory
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...uuid.UUID) predicate.PostCategory
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id uuid.UUID) predicate.PostCategory
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id uuid.UUID) predicate.PostCategory
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id uuid.UUID) predicate.PostCategory
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...uuid.UUID) predicate.PostCategory
IDNotIn applies the NotIn predicate on the ID field.
func Not ¶
func Not(p predicate.PostCategory) predicate.PostCategory
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.PostCategory) predicate.PostCategory
Or groups predicates with the OR operator between them.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.PostCategory
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.PostCategory
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.PostCategory
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.PostCategory
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.PostCategory
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.PostCategory
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.PostCategory
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.PostCategory
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.PostCategory
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type Category ¶
type Category string
Category defines the type for the "category" enum field.
const ( CategoryRANA Category = "RANA" CategorySIN_SONIDO Category = "SIN_SONIDO" CategoryMEME_ARTESANAL Category = "MEME_ARTESANAL" CategoryNO_SE_YO Category = "NO_SE_YO" CategoryORO Category = "ORO" CategoryDIAMANTE Category = "DIAMANTE" CategoryMEH Category = "MEH" CategoryALERTA_GLONETILLO Category = "ALERTA_GLONETILLO" CategoryGRR Category = "GRR" CategoryENSORDECEDOR Category = "ENSORDECEDOR" CategoryRAGUUUL Category = "RAGUUUL" )
Category values.
func (Category) MarshalGQL ¶
MarshalGQL implements graphql.Marshaler interface.
func (*Category) UnmarshalGQL ¶
UnmarshalGQL implements graphql.Unmarshaler interface.
type OrderOption ¶
OrderOption defines the ordering options for the PostCategory queries.
func ByCategory ¶
func ByCategory(opts ...sql.OrderTermOption) OrderOption
ByCategory orders the results by the category field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByPostField ¶
func ByPostField(field string, opts ...sql.OrderTermOption) OrderOption
ByPostField orders the results by post field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.